# XRPrimer

## Introduction

XRPrimer is a fundational library for XR-related algorithms.
The XRPrimer provides reusable data structures, efficient operaters and extensible interfaces both in C++ and Python.


## Getting Started

### C++

Please see [C++ README](cpp/README.md) for the C++ usage

### Python

Please see [Python README](python/README.md) for the Python usage
